@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """Release data for PyGraphviz."""
 
-#    Copyright (C) 2006-2011 by 
-#    Aric Hagberg <hagberg@lanl.gov>
+#    Copyright (C) 2006-2013 by 
+#    Aric Hagberg <aric.hagberg@gmail.com>
 #    Dan Schult <dschult@colgate.edu>
 #    Manos Renieris, http://www.cs.brown.edu/~er/
 #    Distributed with BSD license.     
@@ -63,7 +63,7 @@ def get_svn_revision():
         return None
 
 name = 'pygraphviz'
-version = '1.1'
+version = '1.2'
 
 # Declare current release as a development release.
 # Change to False before tagging a release; then change back.
@@ -78,16 +78,16 @@ if dev:
 
 description = "Python interface to Graphviz"
 long_description = """\
-PyGraphviz is a Python interface to the Graphviz graph layout and visualization package. With PyGraphviz you can create, edit, read, write, and draw graphs using Python to access the Graphviz graph data structure and layout algorithms. PyGraphviz is independent from NetworkX but provides a similar programming interface. 
+PyGraphviz is a Python interface to the Graphviz graph layout and visualization package. With PyGraphviz you can create, edit, read, write, and draw graphs using Python to access the Graphviz graph data structure and layout algorithms. PyGraphviz provides a similar programming interface to NetworkX (http://networkx.github.io). 
 """
 license = 'BSD'
 
-authors = {'Hagberg' : ('Aric Hagberg','hagberg@lanl.gov'),
+authors = {'Hagberg' : ('Aric Hagberg','aric.hagberg@gmail.com'),
            'Schult' : ('Dan Schult','dschult@colgate.edu'),
            'Renieris' : ('Manos Renieris','')
            }
-url = 'http://networkx.lanl.gov/pygraphviz'
-download_url="http://networkx.lanl.gov/download/pygraphviz"
+url = 'http://pygraphviz.github.io'
+download_url="https://pypi.python.org/pypi/pygraphviz"
 platforms = ['Linux','Mac OSX']
 keywords = ['Networks', 'Graph Visualization', 'network', 'graph', 'graph drawing']
 classifiers = [
