@@ -5,7 +5,7 @@ Do not add this file to the repository.
 
 """
 
-__version__ = '1.1'
+__version__ = '1.2'
 __revision__ = None
-__date__ = 'Sat May 14 12:12:14 2011'
+__date__ = 'Sat Aug  3 09:57:44 2013'
 
